==> libreoffice-5.4.6.2.tar.xz: libreoffice-5.4.6.2/chart2/source/controller/dialogs/TextDirectionListBox.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */

#include "TextDirectionListBox.hxx"
#include "ResId.hxx"
#include "Strings.hrc"
#include <svl/languageoptions.hxx>
#include <vcl/window.hxx>
#include <vcl/builderfactory.hxx>

namespace chart
{

TextDirectionListBox::TextDirectionListBox( vcl::Window* pParent ) :
    svx::FrameDirectionListBox( pParent, WB_BORDER | WB_TABSTOP | WB_DROPDOWN)
{
    InsertEntryValue( SchResId( STR_TEXT_DIRECTION_LTR ), SvxFrameDirection::Horizontal_LR_TB );
    InsertEntryValue( SchResId( STR_TEXT_DIRECTION_RTL ), SvxFrameDirection::Horizontal_RL_TB );
    InsertEntryValue( SchResId( STR_TEXT_DIRECTION_SUPER ), SvxFrameDirection::Environment );

    if( !SvtLanguageOptions().IsCTLFontEnabled() )
    {
        Hide();
    }
}

VCL_BUILDER_FACTORY(TextDirectionListBox)

} //namespace chart

/* vim:set shiftwidth=4 softtabstop=4 expandtab: */

==> libreoffice_6.0.3.orig.tar.xz: libreoffice-6.0.3/chart2/source/controller/dialogs/TextDirectionListBox.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */

#include <TextDirectionListBox.hxx>
#include <ResId.hxx>
#include <strings.hrc>
#include <svl/languageoptions.hxx>
#include <vcl/window.hxx>
#include <vcl/builderfactory.hxx>

namespace chart
{

TextDirectionListBox::TextDirectionListBox( vcl::Window* pParent ) :
    svx::FrameDirectionListBox( pParent, WB_BORDER | WB_TABSTOP | WB_DROPDOWN)
{
    InsertEntryValue( SchResId( STR_TEXT_DIRECTION_LTR ), SvxFrameDirection::Horizontal_LR_TB );
    InsertEntryValue( SchResId( STR_TEXT_DIRECTION_RTL ), SvxFrameDirection::Horizontal_RL_TB );
    InsertEntryValue( SchResId( STR_TEXT_DIRECTION_SUPER ), SvxFrameDirection::Environment );

    if( !SvtLanguageOptions().IsCTLFontEnabled() )
    {
        Hide();
    }
}

VCL_BUILDER_FACTORY(TextDirectionListBox)

} //namespace chart

/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
